@@ -25,4 +25,10 @@ def draw_word_cloud(word):
 
 def analysis_text_expression(text):
     s = SnowNLP(text)
-    print(text,'的情感倾向得分为' ,s.sentiments) 
\ No newline at end of file
+    if s.sentiments <= 0.4:
+        commment = '表现为消极情绪倾向'
+    elif s.sentiments > 0.4 and s.sentiments <= 0.6:
+        commment = '表现为中立情绪倾向'
+    else:
+        commment = '表现为积极情绪倾向'
+    print('该文本的情感倾向得分为：' ,s.sentiments,commment) 
\ No newline at end of file
